# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messages.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import variant_pb2 as variant__pb2
from . import variant2_pb2 as variant2__pb2
from . import agent_info_pb2 as agent__info__pb2
from . import controller_info_pb2 as controller__info__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='messages.proto',
  package='com.rookout',
  syntax='proto3',
  serialized_options=b'\n\031com.rookout.rook.protobufZ2github.com/Rookout/management/pkg/protos/protobuf2',
  serialized_pb=b'\n\x0emessages.proto\x12\x0b\x63om.rookout\x1a\rvariant.proto\x1a\x0evariant2.proto\x1a\x10\x61gent_info.proto\x1a\x15\x63ontroller_info.proto\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"D\n\x0fNewAgentMessage\x12\x31\n\nagent_info\x18\x01 \x01(\x0b\x32\x1d.com.rookout.AgentInformation\">\n\nStackFrame\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0c\n\x04line\x18\x02 \x01(\r\x12\x10\n\x08\x66unction\x18\x03 \x01(\t\"5\n\nStackTrace\x12\'\n\x06\x66rames\x18\x01 \x03(\x0b\x32\x17.com.rookout.StackFrame\"~\n\tException\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12&\n\x08instance\x18\x03 \x01(\x0b\x32\x14.com.rookout.Variant\x12*\n\ttraceback\x18\x04 \x01(\x0b\x32\x17.com.rookout.StackTrace\"\xe2\x03\n\nLogMessage\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x61gent_id\x18\x02 \x01(\t\x12/\n\x05level\x18\x03 \x01(\x0e\x32 .com.rookout.LogMessage.LogLevel\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12\x0c\n\x04line\x18\x05 \x01(\r\x12\x0c\n\x04text\x18\x06 \x01(\t\x12\'\n\targuments\x18\x07 \x03(\x0b\x32\x14.com.rookout.Variant\x12)\n\texception\x18\x08 \x01(\x0b\x32\x16.com.rookout.Exception\x12\x1d\n\x11\x66ormatted_message\x18\t \x01(\tB\x02\x18\x01\x12\x32\n\x10legacy_arguments\x18\n \x01(\x0b\x32\x14.com.rookout.VariantB\x02\x18\x01\x12\x12\n\nclass_name\x18\x0b \x01(\t\x12\x13\n\x0bmethod_name\x18\x0c \x01(\t\x12\x15\n\rcontroller_id\x18\r \x01(\t\"M\n\x08LogLevel\x12\t\n\x05TRACE\x10\x00\x12\t\n\x05\x44\x45\x42UG\x10\x01\x12\x08\n\x04INFO\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\t\n\x05\x46\x41TAL\x10\x05\"\xa3\x05\n\x14\x43ontrollerLogMessage\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x05level\x18\x02 \x01(\x0e\x32*.com.rookout.ControllerLogMessage.LogLevel\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\x12\x0c\n\x04line\x18\x04 \x01(\r\x12\x0c\n\x04text\x18\x05 \x01(\t\x12\x12\n\nclass_name\x18\x06 \x01(\t\x12\x13\n\x0bmethod_name\x18\x07 \x01(\t\x12\x15\n\rcontroller_id\x18\x08 \x01(\t\x12\x36\n\x05\x65rror\x18\t \x01(\x0b\x32\'.com.rookout.ControllerLogMessage.Error\x12\x41\n\x08metadata\x18\n \x03(\x0b\x32/.com.rookout.ControllerLogMessage.MetadataEntry\x12U\n\x12metadataJSONValues\x18\x0b \x03(\x0b\x32\x39.com.rookout.ControllerLogMessage.MetadataJSONValuesEntry\x1a&\n\x05\x45rror\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x39\n\x17MetadataJSONValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"M\n\x08LogLevel\x12\t\n\x05TRACE\x10\x00\x12\t\n\x05\x44\x45\x42UG\x10\x01\x12\x08\n\x04INFO\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\t\n\x05\x46\x41TAL\x10\x05\"\x80\x01\n\x11RuleStatusMessage\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\x12\x0f\n\x07rule_id\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x03 \x01(\t\x12!\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x12.com.rookout.Error\x12\x15\n\rcontroller_id\x18\x05 \x01(\t\"\xf0\x02\n\x10\x41ugReportMessage\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61ug_id\x18\x02 \x01(\t\x12\'\n\targuments\x18\x03 \x01(\x0b\x32\x14.com.rookout.Variant\x12\x11\n\treport_id\x18\x04 \x01(\t\x12\x46\n\rstrings_cache\x18\x05 \x03(\x0b\x32/.com.rookout.AugReportMessage.StringsCacheEntry\x12\x1c\n\x14\x62uffer_cache_buffers\x18\x06 \x03(\x0c\x12\x1c\n\x14\x62uffer_cache_indexes\x18\x07 \x03(\r\x12)\n\narguments2\x18\x08 \x01(\x0b\x32\x15.com.rookout.Variant2\x12\x1a\n\x12reverse_list_order\x18\t \x01(\x08\x1a\x33\n\x11StringsCacheEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\"e\n\x07UserMsg\x12\x31\n\naug_report\x18\x01 \x01(\x0b\x32\x1d.com.rookout.AugReportMessage\x12\x11\n\treport_id\x18\x02 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x03 \x01(\t\"!\n\rAddAugCommand\x12\x10\n\x08\x61ug_json\x18\x01 \x01(\t\"\xad\x01\n\x12InitialAugsCommand\x12\x0c\n\x04\x61ugs\x18\x01 \x03(\t\x12P\n\x11sdk_configuration\x18\x02 \x03(\x0b\x32\x35.com.rookout.InitialAugsCommand.SdkConfigurationEntry\x1a\x37\n\x15SdkConfigurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\"\n\x10RemoveAugCommand\x12\x0e\n\x06\x61ug_id\x18\x01 \x01(\t\"\x15\n\x13InitFinishedMessage\"\x12\n\x10\x43learAugsCommand\"\x1c\n\x0bPingMessage\x12\r\n\x05value\x18\x01 \x01(\x05\"\x1f\n\x0c\x45rrorMessage\x12\x0f\n\x07message\x18\x01 \x01(\t\"e\n\x0e\x43\x32\x43InitMessage\x12:\n\x0e\x63ontrollerInfo\x18\x01 \x01(\x0b\x32\".com.rookout.ControllerInformation\x12\x17\n\x0f\x63onnectedAgents\x18\x02 \x03(\t\"U\n\x16\x44\x61taOnPremTokenRequest\x12;\n\x0b\x61\x63\x63\x65ss_type\x18\x01 \x01(\x0e\x32&.com.rookout.DataOnPremTokenAccessType\"(\n\x17\x44\x61taOnPremTokenResponse\x12\r\n\x05token\x18\x01 \x01(\x0c\" \n\nAgentsList\x12\x12\n\nagents_ids\x18\x01 \x03(\t\"!\n\x0c\x41ssertAgents\x12\x11\n\tagent_ids\x18\x01 \x03(\t\"-\n\x17InvalidateAgentsCommand\x12\x12\n\nagents_ids\x18\x01 \x03(\t\"*\n\x14\x43onfirmAgentsCommand\x12\x12\n\nagents_ids\x18\x01 \x03(\t\":\n\x13\x41gentIdHitCountPair\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\x12\x11\n\thit_count\x18\x02 \x01(\r\"f\n\x15HitCountUpdateMessage\x12\x0e\n\x06\x61ug_id\x18\x01 \x01(\t\x12=\n\x13hitCountInformation\x18\x02 \x03(\x0b\x32 .com.rookout.AgentIdHitCountPair\"L\n\rC2cRpcRequest\x12\x14\n\x0crequest_uuid\x18\x01 \x01(\t\x12%\n\x07message\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"\\\n\x0e\x43\x32\x63RpcResponse\x12\x14\n\x0crequest_uuid\x18\x01 \x01(\t\x12%\n\x07message\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"w\n%StartDatastoreConnectivityTestCommand\x12\r\n\x05orgId\x18\x01 \x01(\t\x12\x14\n\x0c\x63ontrollerId\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61tastoreUrl\x18\x03 \x01(\t\x12\x13\n\x0bworkspaceId\x18\x04 \x01(\t\"{\n$DatastoreConnectivityTestC2cResponse\x12\x14\n\x0c\x63ontrollerId\x18\x01 \x01(\t\x12\x15\n\rTestMessageId\x18\x02 \x01(\t\x12\x11\n\tisSuccess\x18\x03 \x01(\x08\x12\x13\n\x0b\x65rrorString\x18\x04 \x01(\t\",\n\x14PingDatastoreCommand\x12\x14\n\x0c\x64\x61tastoreUrl\x18\x01 \x01(\t\"\xb3\x01\n\x14\x44\x61tastoreInformation\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x10\n\x08hostname\x18\x02 \x01(\t\x12\x14\n\x0cmachine_type\x18\x03 \x01(\t\x12\x0f\n\x07network\x18\x04 \x01(\t\x12\n\n\x02ip\x18\x05 \x01(\t\x12\n\n\x02os\x18\x06 \x01(\t\x12\x12\n\nos_release\x18\x07 \x01(\t\x12\x12\n\nos_version\x18\x08 \x01(\t\x12\x11\n\tos_string\x18\t \x01(\t*0\n\x19\x44\x61taOnPremTokenAccessType\x12\t\n\x05WRITE\x10\x00\x12\x08\n\x04READ\x10\x01\x42O\n\x19\x63om.rookout.rook.protobufZ2github.com/Rookout/management/pkg/protos/protobuf2b\x06proto3'
  ,
  dependencies=[variant__pb2.DESCRIPTOR,variant2__pb2.DESCRIPTOR,agent__info__pb2.DESCRIPTOR,controller__info__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_DATAONPREMTOKENACCESSTYPE = _descriptor.EnumDescriptor(
  name='DataOnPremTokenAccessType',
  full_name='com.rookout.DataOnPremTokenAccessType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WRITE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READ', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3803,
  serialized_end=3851,
)
_sym_db.RegisterEnumDescriptor(_DATAONPREMTOKENACCESSTYPE)

DataOnPremTokenAccessType = enum_type_wrapper.EnumTypeWrapper(_DATAONPREMTOKENACCESSTYPE)
WRITE = 0
READ = 1


_LOGMESSAGE_LOGLEVEL = _descriptor.EnumDescriptor(
  name='LogLevel',
  full_name='com.rookout.LogMessage.LogLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRACE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEBUG', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INFO', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FATAL', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=886,
  serialized_end=963,
)
_sym_db.RegisterEnumDescriptor(_LOGMESSAGE_LOGLEVEL)

_CONTROLLERLOGMESSAGE_LOGLEVEL = _descriptor.EnumDescriptor(
  name='LogLevel',
  full_name='com.rookout.ControllerLogMessage.LogLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRACE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEBUG', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INFO', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FATAL', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=886,
  serialized_end=963,
)
_sym_db.RegisterEnumDescriptor(_CONTROLLERLOGMESSAGE_LOGLEVEL)


_NEWAGENTMESSAGE = _descriptor.Descriptor(
  name='NewAgentMessage',
  full_name='com.rookout.NewAgentMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_info', full_name='com.rookout.NewAgentMessage.agent_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=231,
)


_STACKFRAME = _descriptor.Descriptor(
  name='StackFrame',
  full_name='com.rookout.StackFrame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='com.rookout.StackFrame.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line', full_name='com.rookout.StackFrame.line', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='function', full_name='com.rookout.StackFrame.function', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=295,
)


_STACKTRACE = _descriptor.Descriptor(
  name='StackTrace',
  full_name='com.rookout.StackTrace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='frames', full_name='com.rookout.StackTrace.frames', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=297,
  serialized_end=350,
)


_EXCEPTION = _descriptor.Descriptor(
  name='Exception',
  full_name='com.rookout.Exception',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='com.rookout.Exception.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.rookout.Exception.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instance', full_name='com.rookout.Exception.instance', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='traceback', full_name='com.rookout.Exception.traceback', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=478,
)


_LOGMESSAGE = _descriptor.Descriptor(
  name='LogMessage',
  full_name='com.rookout.LogMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='com.rookout.LogMessage.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='agent_id', full_name='com.rookout.LogMessage.agent_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='com.rookout.LogMessage.level', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filename', full_name='com.rookout.LogMessage.filename', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line', full_name='com.rookout.LogMessage.line', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='com.rookout.LogMessage.text', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='com.rookout.LogMessage.arguments', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exception', full_name='com.rookout.LogMessage.exception', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formatted_message', full_name='com.rookout.LogMessage.formatted_message', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legacy_arguments', full_name='com.rookout.LogMessage.legacy_arguments', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='class_name', full_name='com.rookout.LogMessage.class_name', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method_name', full_name='com.rookout.LogMessage.method_name', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='controller_id', full_name='com.rookout.LogMessage.controller_id', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOGMESSAGE_LOGLEVEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=481,
  serialized_end=963,
)


_CONTROLLERLOGMESSAGE_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='com.rookout.ControllerLogMessage.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='com.rookout.ControllerLogMessage.Error.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.rookout.ControllerLogMessage.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1416,
  serialized_end=1454,
)

_CONTROLLERLOGMESSAGE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='com.rookout.ControllerLogMessage.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.rookout.ControllerLogMessage.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.rookout.ControllerLogMessage.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1456,
  serialized_end=1503,
)

_CONTROLLERLOGMESSAGE_METADATAJSONVALUESENTRY = _descriptor.Descriptor(
  name='MetadataJSONValuesEntry',
  full_name='com.rookout.ControllerLogMessage.MetadataJSONValuesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.rookout.ControllerLogMessage.MetadataJSONValuesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.rookout.ControllerLogMessage.MetadataJSONValuesEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1505,
  serialized_end=1562,
)

_CONTROLLERLOGMESSAGE = _descriptor.Descriptor(
  name='ControllerLogMessage',
  full_name='com.rookout.ControllerLogMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='com.rookout.ControllerLogMessage.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='com.rookout.ControllerLogMessage.level', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filename', full_name='com.rookout.ControllerLogMessage.filename', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line', full_name='com.rookout.ControllerLogMessage.line', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='com.rookout.ControllerLogMessage.text', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='class_name', full_name='com.rookout.ControllerLogMessage.class_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method_name', full_name='com.rookout.ControllerLogMessage.method_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='controller_id', full_name='com.rookout.ControllerLogMessage.controller_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='com.rookout.ControllerLogMessage.error', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='com.rookout.ControllerLogMessage.metadata', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadataJSONValues', full_name='com.rookout.ControllerLogMessage.metadataJSONValues', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CONTROLLERLOGMESSAGE_ERROR, _CONTROLLERLOGMESSAGE_METADATAENTRY, _CONTROLLERLOGMESSAGE_METADATAJSONVALUESENTRY, ],
  enum_types=[
    _CONTROLLERLOGMESSAGE_LOGLEVEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=966,
  serialized_end=1641,
)


_RULESTATUSMESSAGE = _descriptor.Descriptor(
  name='RuleStatusMessage',
  full_name='com.rookout.RuleStatusMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_id', full_name='com.rookout.RuleStatusMessage.agent_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_id', full_name='com.rookout.RuleStatusMessage.rule_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active', full_name='com.rookout.RuleStatusMessage.active', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='com.rookout.RuleStatusMessage.error', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='controller_id', full_name='com.rookout.RuleStatusMessage.controller_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1644,
  serialized_end=1772,
)


_AUGREPORTMESSAGE_STRINGSCACHEENTRY = _descriptor.Descriptor(
  name='StringsCacheEntry',
  full_name='com.rookout.AugReportMessage.StringsCacheEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.rookout.AugReportMessage.StringsCacheEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.rookout.AugReportMessage.StringsCacheEntry.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2092,
  serialized_end=2143,
)

_AUGREPORTMESSAGE = _descriptor.Descriptor(
  name='AugReportMessage',
  full_name='com.rookout.AugReportMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_id', full_name='com.rookout.AugReportMessage.agent_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aug_id', full_name='com.rookout.AugReportMessage.aug_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='com.rookout.AugReportMessage.arguments', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='report_id', full_name='com.rookout.AugReportMessage.report_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strings_cache', full_name='com.rookout.AugReportMessage.strings_cache', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buffer_cache_buffers', full_name='com.rookout.AugReportMessage.buffer_cache_buffers', index=5,
      number=6, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buffer_cache_indexes', full_name='com.rookout.AugReportMessage.buffer_cache_indexes', index=6,
      number=7, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arguments2', full_name='com.rookout.AugReportMessage.arguments2', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reverse_list_order', full_name='com.rookout.AugReportMessage.reverse_list_order', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_AUGREPORTMESSAGE_STRINGSCACHEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1775,
  serialized_end=2143,
)


_USERMSG = _descriptor.Descriptor(
  name='UserMsg',
  full_name='com.rookout.UserMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='aug_report', full_name='com.rookout.UserMsg.aug_report', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='report_id', full_name='com.rookout.UserMsg.report_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workspace_id', full_name='com.rookout.UserMsg.workspace_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2145,
  serialized_end=2246,
)


_ADDAUGCOMMAND = _descriptor.Descriptor(
  name='AddAugCommand',
  full_name='com.rookout.AddAugCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='aug_json', full_name='com.rookout.AddAugCommand.aug_json', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2248,
  serialized_end=2281,
)


_INITIALAUGSCOMMAND_SDKCONFIGURATIONENTRY = _descriptor.Descriptor(
  name='SdkConfigurationEntry',
  full_name='com.rookout.InitialAugsCommand.SdkConfigurationEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.rookout.InitialAugsCommand.SdkConfigurationEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.rookout.InitialAugsCommand.SdkConfigurationEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2402,
  serialized_end=2457,
)

_INITIALAUGSCOMMAND = _descriptor.Descriptor(
  name='InitialAugsCommand',
  full_name='com.rookout.InitialAugsCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='augs', full_name='com.rookout.InitialAugsCommand.augs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sdk_configuration', full_name='com.rookout.InitialAugsCommand.sdk_configuration', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INITIALAUGSCOMMAND_SDKCONFIGURATIONENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2284,
  serialized_end=2457,
)


_REMOVEAUGCOMMAND = _descriptor.Descriptor(
  name='RemoveAugCommand',
  full_name='com.rookout.RemoveAugCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='aug_id', full_name='com.rookout.RemoveAugCommand.aug_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2459,
  serialized_end=2493,
)


_INITFINISHEDMESSAGE = _descriptor.Descriptor(
  name='InitFinishedMessage',
  full_name='com.rookout.InitFinishedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2495,
  serialized_end=2516,
)


_CLEARAUGSCOMMAND = _descriptor.Descriptor(
  name='ClearAugsCommand',
  full_name='com.rookout.ClearAugsCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2518,
  serialized_end=2536,
)


_PINGMESSAGE = _descriptor.Descriptor(
  name='PingMessage',
  full_name='com.rookout.PingMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='com.rookout.PingMessage.value', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2538,
  serialized_end=2566,
)


_ERRORMESSAGE = _descriptor.Descriptor(
  name='ErrorMessage',
  full_name='com.rookout.ErrorMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='com.rookout.ErrorMessage.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2568,
  serialized_end=2599,
)


_C2CINITMESSAGE = _descriptor.Descriptor(
  name='C2CInitMessage',
  full_name='com.rookout.C2CInitMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='controllerInfo', full_name='com.rookout.C2CInitMessage.controllerInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connectedAgents', full_name='com.rookout.C2CInitMessage.connectedAgents', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2601,
  serialized_end=2702,
)


_DATAONPREMTOKENREQUEST = _descriptor.Descriptor(
  name='DataOnPremTokenRequest',
  full_name='com.rookout.DataOnPremTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_type', full_name='com.rookout.DataOnPremTokenRequest.access_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2704,
  serialized_end=2789,
)


_DATAONPREMTOKENRESPONSE = _descriptor.Descriptor(
  name='DataOnPremTokenResponse',
  full_name='com.rookout.DataOnPremTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='com.rookout.DataOnPremTokenResponse.token', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2791,
  serialized_end=2831,
)


_AGENTSLIST = _descriptor.Descriptor(
  name='AgentsList',
  full_name='com.rookout.AgentsList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agents_ids', full_name='com.rookout.AgentsList.agents_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2833,
  serialized_end=2865,
)


_ASSERTAGENTS = _descriptor.Descriptor(
  name='AssertAgents',
  full_name='com.rookout.AssertAgents',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_ids', full_name='com.rookout.AssertAgents.agent_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2867,
  serialized_end=2900,
)


_INVALIDATEAGENTSCOMMAND = _descriptor.Descriptor(
  name='InvalidateAgentsCommand',
  full_name='com.rookout.InvalidateAgentsCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agents_ids', full_name='com.rookout.InvalidateAgentsCommand.agents_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2902,
  serialized_end=2947,
)


_CONFIRMAGENTSCOMMAND = _descriptor.Descriptor(
  name='ConfirmAgentsCommand',
  full_name='com.rookout.ConfirmAgentsCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agents_ids', full_name='com.rookout.ConfirmAgentsCommand.agents_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2949,
  serialized_end=2991,
)


_AGENTIDHITCOUNTPAIR = _descriptor.Descriptor(
  name='AgentIdHitCountPair',
  full_name='com.rookout.AgentIdHitCountPair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_id', full_name='com.rookout.AgentIdHitCountPair.agent_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hit_count', full_name='com.rookout.AgentIdHitCountPair.hit_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2993,
  serialized_end=3051,
)


_HITCOUNTUPDATEMESSAGE = _descriptor.Descriptor(
  name='HitCountUpdateMessage',
  full_name='com.rookout.HitCountUpdateMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='aug_id', full_name='com.rookout.HitCountUpdateMessage.aug_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hitCountInformation', full_name='com.rookout.HitCountUpdateMessage.hitCountInformation', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3053,
  serialized_end=3155,
)


_C2CRPCREQUEST = _descriptor.Descriptor(
  name='C2cRpcRequest',
  full_name='com.rookout.C2cRpcRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_uuid', full_name='com.rookout.C2cRpcRequest.request_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.rookout.C2cRpcRequest.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3157,
  serialized_end=3233,
)


_C2CRPCRESPONSE = _descriptor.Descriptor(
  name='C2cRpcResponse',
  full_name='com.rookout.C2cRpcResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_uuid', full_name='com.rookout.C2cRpcResponse.request_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.rookout.C2cRpcResponse.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='com.rookout.C2cRpcResponse.error', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3235,
  serialized_end=3327,
)


_STARTDATASTORECONNECTIVITYTESTCOMMAND = _descriptor.Descriptor(
  name='StartDatastoreConnectivityTestCommand',
  full_name='com.rookout.StartDatastoreConnectivityTestCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orgId', full_name='com.rookout.StartDatastoreConnectivityTestCommand.orgId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='controllerId', full_name='com.rookout.StartDatastoreConnectivityTestCommand.controllerId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datastoreUrl', full_name='com.rookout.StartDatastoreConnectivityTestCommand.datastoreUrl', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workspaceId', full_name='com.rookout.StartDatastoreConnectivityTestCommand.workspaceId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3329,
  serialized_end=3448,
)


_DATASTORECONNECTIVITYTESTC2CRESPONSE = _descriptor.Descriptor(
  name='DatastoreConnectivityTestC2cResponse',
  full_name='com.rookout.DatastoreConnectivityTestC2cResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='controllerId', full_name='com.rookout.DatastoreConnectivityTestC2cResponse.controllerId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='TestMessageId', full_name='com.rookout.DatastoreConnectivityTestC2cResponse.TestMessageId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isSuccess', full_name='com.rookout.DatastoreConnectivityTestC2cResponse.isSuccess', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorString', full_name='com.rookout.DatastoreConnectivityTestC2cResponse.errorString', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3450,
  serialized_end=3573,
)


_PINGDATASTORECOMMAND = _descriptor.Descriptor(
  name='PingDatastoreCommand',
  full_name='com.rookout.PingDatastoreCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='datastoreUrl', full_name='com.rookout.PingDatastoreCommand.datastoreUrl', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3575,
  serialized_end=3619,
)


_DATASTOREINFORMATION = _descriptor.Descriptor(
  name='DatastoreInformation',
  full_name='com.rookout.DatastoreInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='com.rookout.DatastoreInformation.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='com.rookout.DatastoreInformation.hostname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='machine_type', full_name='com.rookout.DatastoreInformation.machine_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='network', full_name='com.rookout.DatastoreInformation.network', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ip', full_name='com.rookout.DatastoreInformation.ip', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='os', full_name='com.rookout.DatastoreInformation.os', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='os_release', full_name='com.rookout.DatastoreInformation.os_release', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='os_version', full_name='com.rookout.DatastoreInformation.os_version', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='os_string', full_name='com.rookout.DatastoreInformation.os_string', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3622,
  serialized_end=3801,
)

_NEWAGENTMESSAGE.fields_by_name['agent_info'].message_type = agent__info__pb2._AGENTINFORMATION
_STACKTRACE.fields_by_name['frames'].message_type = _STACKFRAME
_EXCEPTION.fields_by_name['instance'].message_type = variant__pb2._VARIANT
_EXCEPTION.fields_by_name['traceback'].message_type = _STACKTRACE
_LOGMESSAGE.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LOGMESSAGE.fields_by_name['level'].enum_type = _LOGMESSAGE_LOGLEVEL
_LOGMESSAGE.fields_by_name['arguments'].message_type = variant__pb2._VARIANT
_LOGMESSAGE.fields_by_name['exception'].message_type = _EXCEPTION
_LOGMESSAGE.fields_by_name['legacy_arguments'].message_type = variant__pb2._VARIANT
_LOGMESSAGE_LOGLEVEL.containing_type = _LOGMESSAGE
_CONTROLLERLOGMESSAGE_ERROR.containing_type = _CONTROLLERLOGMESSAGE
_CONTROLLERLOGMESSAGE_METADATAENTRY.containing_type = _CONTROLLERLOGMESSAGE
_CONTROLLERLOGMESSAGE_METADATAJSONVALUESENTRY.containing_type = _CONTROLLERLOGMESSAGE
_CONTROLLERLOGMESSAGE.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CONTROLLERLOGMESSAGE.fields_by_name['level'].enum_type = _CONTROLLERLOGMESSAGE_LOGLEVEL
_CONTROLLERLOGMESSAGE.fields_by_name['error'].message_type = _CONTROLLERLOGMESSAGE_ERROR
_CONTROLLERLOGMESSAGE.fields_by_name['metadata'].message_type = _CONTROLLERLOGMESSAGE_METADATAENTRY
_CONTROLLERLOGMESSAGE.fields_by_name['metadataJSONValues'].message_type = _CONTROLLERLOGMESSAGE_METADATAJSONVALUESENTRY
_CONTROLLERLOGMESSAGE_LOGLEVEL.containing_type = _CONTROLLERLOGMESSAGE
_RULESTATUSMESSAGE.fields_by_name['error'].message_type = variant__pb2._ERROR
_AUGREPORTMESSAGE_STRINGSCACHEENTRY.containing_type = _AUGREPORTMESSAGE
_AUGREPORTMESSAGE.fields_by_name['arguments'].message_type = variant__pb2._VARIANT
_AUGREPORTMESSAGE.fields_by_name['strings_cache'].message_type = _AUGREPORTMESSAGE_STRINGSCACHEENTRY
_AUGREPORTMESSAGE.fields_by_name['arguments2'].message_type = variant2__pb2._VARIANT2
_USERMSG.fields_by_name['aug_report'].message_type = _AUGREPORTMESSAGE
_INITIALAUGSCOMMAND_SDKCONFIGURATIONENTRY.containing_type = _INITIALAUGSCOMMAND
_INITIALAUGSCOMMAND.fields_by_name['sdk_configuration'].message_type = _INITIALAUGSCOMMAND_SDKCONFIGURATIONENTRY
_C2CINITMESSAGE.fields_by_name['controllerInfo'].message_type = controller__info__pb2._CONTROLLERINFORMATION
_DATAONPREMTOKENREQUEST.fields_by_name['access_type'].enum_type = _DATAONPREMTOKENACCESSTYPE
_HITCOUNTUPDATEMESSAGE.fields_by_name['hitCountInformation'].message_type = _AGENTIDHITCOUNTPAIR
_C2CRPCREQUEST.fields_by_name['message'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_C2CRPCRESPONSE.fields_by_name['message'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['NewAgentMessage'] = _NEWAGENTMESSAGE
DESCRIPTOR.message_types_by_name['StackFrame'] = _STACKFRAME
DESCRIPTOR.message_types_by_name['StackTrace'] = _STACKTRACE
DESCRIPTOR.message_types_by_name['Exception'] = _EXCEPTION
DESCRIPTOR.message_types_by_name['LogMessage'] = _LOGMESSAGE
DESCRIPTOR.message_types_by_name['ControllerLogMessage'] = _CONTROLLERLOGMESSAGE
DESCRIPTOR.message_types_by_name['RuleStatusMessage'] = _RULESTATUSMESSAGE
DESCRIPTOR.message_types_by_name['AugReportMessage'] = _AUGREPORTMESSAGE
DESCRIPTOR.message_types_by_name['UserMsg'] = _USERMSG
DESCRIPTOR.message_types_by_name['AddAugCommand'] = _ADDAUGCOMMAND
DESCRIPTOR.message_types_by_name['InitialAugsCommand'] = _INITIALAUGSCOMMAND
DESCRIPTOR.message_types_by_name['RemoveAugCommand'] = _REMOVEAUGCOMMAND
DESCRIPTOR.message_types_by_name['InitFinishedMessage'] = _INITFINISHEDMESSAGE
DESCRIPTOR.message_types_by_name['ClearAugsCommand'] = _CLEARAUGSCOMMAND
DESCRIPTOR.message_types_by_name['PingMessage'] = _PINGMESSAGE
DESCRIPTOR.message_types_by_name['ErrorMessage'] = _ERRORMESSAGE
DESCRIPTOR.message_types_by_name['C2CInitMessage'] = _C2CINITMESSAGE
DESCRIPTOR.message_types_by_name['DataOnPremTokenRequest'] = _DATAONPREMTOKENREQUEST
DESCRIPTOR.message_types_by_name['DataOnPremTokenResponse'] = _DATAONPREMTOKENRESPONSE
DESCRIPTOR.message_types_by_name['AgentsList'] = _AGENTSLIST
DESCRIPTOR.message_types_by_name['AssertAgents'] = _ASSERTAGENTS
DESCRIPTOR.message_types_by_name['InvalidateAgentsCommand'] = _INVALIDATEAGENTSCOMMAND
DESCRIPTOR.message_types_by_name['ConfirmAgentsCommand'] = _CONFIRMAGENTSCOMMAND
DESCRIPTOR.message_types_by_name['AgentIdHitCountPair'] = _AGENTIDHITCOUNTPAIR
DESCRIPTOR.message_types_by_name['HitCountUpdateMessage'] = _HITCOUNTUPDATEMESSAGE
DESCRIPTOR.message_types_by_name['C2cRpcRequest'] = _C2CRPCREQUEST
DESCRIPTOR.message_types_by_name['C2cRpcResponse'] = _C2CRPCRESPONSE
DESCRIPTOR.message_types_by_name['StartDatastoreConnectivityTestCommand'] = _STARTDATASTORECONNECTIVITYTESTCOMMAND
DESCRIPTOR.message_types_by_name['DatastoreConnectivityTestC2cResponse'] = _DATASTORECONNECTIVITYTESTC2CRESPONSE
DESCRIPTOR.message_types_by_name['PingDatastoreCommand'] = _PINGDATASTORECOMMAND
DESCRIPTOR.message_types_by_name['DatastoreInformation'] = _DATASTOREINFORMATION
DESCRIPTOR.enum_types_by_name['DataOnPremTokenAccessType'] = _DATAONPREMTOKENACCESSTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NewAgentMessage = _reflection.GeneratedProtocolMessageType('NewAgentMessage', (_message.Message,), {
  'DESCRIPTOR' : _NEWAGENTMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.NewAgentMessage)
  })
_sym_db.RegisterMessage(NewAgentMessage)

StackFrame = _reflection.GeneratedProtocolMessageType('StackFrame', (_message.Message,), {
  'DESCRIPTOR' : _STACKFRAME,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.StackFrame)
  })
_sym_db.RegisterMessage(StackFrame)

StackTrace = _reflection.GeneratedProtocolMessageType('StackTrace', (_message.Message,), {
  'DESCRIPTOR' : _STACKTRACE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.StackTrace)
  })
_sym_db.RegisterMessage(StackTrace)

Exception = _reflection.GeneratedProtocolMessageType('Exception', (_message.Message,), {
  'DESCRIPTOR' : _EXCEPTION,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.Exception)
  })
_sym_db.RegisterMessage(Exception)

LogMessage = _reflection.GeneratedProtocolMessageType('LogMessage', (_message.Message,), {
  'DESCRIPTOR' : _LOGMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.LogMessage)
  })
_sym_db.RegisterMessage(LogMessage)

ControllerLogMessage = _reflection.GeneratedProtocolMessageType('ControllerLogMessage', (_message.Message,), {

  'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
    'DESCRIPTOR' : _CONTROLLERLOGMESSAGE_ERROR,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.ControllerLogMessage.Error)
    })
  ,

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTROLLERLOGMESSAGE_METADATAENTRY,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.ControllerLogMessage.MetadataEntry)
    })
  ,

  'MetadataJSONValuesEntry' : _reflection.GeneratedProtocolMessageType('MetadataJSONValuesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTROLLERLOGMESSAGE_METADATAJSONVALUESENTRY,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.ControllerLogMessage.MetadataJSONValuesEntry)
    })
  ,
  'DESCRIPTOR' : _CONTROLLERLOGMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.ControllerLogMessage)
  })
_sym_db.RegisterMessage(ControllerLogMessage)
_sym_db.RegisterMessage(ControllerLogMessage.Error)
_sym_db.RegisterMessage(ControllerLogMessage.MetadataEntry)
_sym_db.RegisterMessage(ControllerLogMessage.MetadataJSONValuesEntry)

RuleStatusMessage = _reflection.GeneratedProtocolMessageType('RuleStatusMessage', (_message.Message,), {
  'DESCRIPTOR' : _RULESTATUSMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.RuleStatusMessage)
  })
_sym_db.RegisterMessage(RuleStatusMessage)

AugReportMessage = _reflection.GeneratedProtocolMessageType('AugReportMessage', (_message.Message,), {

  'StringsCacheEntry' : _reflection.GeneratedProtocolMessageType('StringsCacheEntry', (_message.Message,), {
    'DESCRIPTOR' : _AUGREPORTMESSAGE_STRINGSCACHEENTRY,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.AugReportMessage.StringsCacheEntry)
    })
  ,
  'DESCRIPTOR' : _AUGREPORTMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.AugReportMessage)
  })
_sym_db.RegisterMessage(AugReportMessage)
_sym_db.RegisterMessage(AugReportMessage.StringsCacheEntry)

UserMsg = _reflection.GeneratedProtocolMessageType('UserMsg', (_message.Message,), {
  'DESCRIPTOR' : _USERMSG,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.UserMsg)
  })
_sym_db.RegisterMessage(UserMsg)

AddAugCommand = _reflection.GeneratedProtocolMessageType('AddAugCommand', (_message.Message,), {
  'DESCRIPTOR' : _ADDAUGCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.AddAugCommand)
  })
_sym_db.RegisterMessage(AddAugCommand)

InitialAugsCommand = _reflection.GeneratedProtocolMessageType('InitialAugsCommand', (_message.Message,), {

  'SdkConfigurationEntry' : _reflection.GeneratedProtocolMessageType('SdkConfigurationEntry', (_message.Message,), {
    'DESCRIPTOR' : _INITIALAUGSCOMMAND_SDKCONFIGURATIONENTRY,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.InitialAugsCommand.SdkConfigurationEntry)
    })
  ,
  'DESCRIPTOR' : _INITIALAUGSCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.InitialAugsCommand)
  })
_sym_db.RegisterMessage(InitialAugsCommand)
_sym_db.RegisterMessage(InitialAugsCommand.SdkConfigurationEntry)

RemoveAugCommand = _reflection.GeneratedProtocolMessageType('RemoveAugCommand', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEAUGCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.RemoveAugCommand)
  })
_sym_db.RegisterMessage(RemoveAugCommand)

InitFinishedMessage = _reflection.GeneratedProtocolMessageType('InitFinishedMessage', (_message.Message,), {
  'DESCRIPTOR' : _INITFINISHEDMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.InitFinishedMessage)
  })
_sym_db.RegisterMessage(InitFinishedMessage)

ClearAugsCommand = _reflection.GeneratedProtocolMessageType('ClearAugsCommand', (_message.Message,), {
  'DESCRIPTOR' : _CLEARAUGSCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.ClearAugsCommand)
  })
_sym_db.RegisterMessage(ClearAugsCommand)

PingMessage = _reflection.GeneratedProtocolMessageType('PingMessage', (_message.Message,), {
  'DESCRIPTOR' : _PINGMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.PingMessage)
  })
_sym_db.RegisterMessage(PingMessage)

ErrorMessage = _reflection.GeneratedProtocolMessageType('ErrorMessage', (_message.Message,), {
  'DESCRIPTOR' : _ERRORMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.ErrorMessage)
  })
_sym_db.RegisterMessage(ErrorMessage)

C2CInitMessage = _reflection.GeneratedProtocolMessageType('C2CInitMessage', (_message.Message,), {
  'DESCRIPTOR' : _C2CINITMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.C2CInitMessage)
  })
_sym_db.RegisterMessage(C2CInitMessage)

DataOnPremTokenRequest = _reflection.GeneratedProtocolMessageType('DataOnPremTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATAONPREMTOKENREQUEST,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.DataOnPremTokenRequest)
  })
_sym_db.RegisterMessage(DataOnPremTokenRequest)

DataOnPremTokenResponse = _reflection.GeneratedProtocolMessageType('DataOnPremTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATAONPREMTOKENRESPONSE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.DataOnPremTokenResponse)
  })
_sym_db.RegisterMessage(DataOnPremTokenResponse)

AgentsList = _reflection.GeneratedProtocolMessageType('AgentsList', (_message.Message,), {
  'DESCRIPTOR' : _AGENTSLIST,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.AgentsList)
  })
_sym_db.RegisterMessage(AgentsList)

AssertAgents = _reflection.GeneratedProtocolMessageType('AssertAgents', (_message.Message,), {
  'DESCRIPTOR' : _ASSERTAGENTS,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.AssertAgents)
  })
_sym_db.RegisterMessage(AssertAgents)

InvalidateAgentsCommand = _reflection.GeneratedProtocolMessageType('InvalidateAgentsCommand', (_message.Message,), {
  'DESCRIPTOR' : _INVALIDATEAGENTSCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.InvalidateAgentsCommand)
  })
_sym_db.RegisterMessage(InvalidateAgentsCommand)

ConfirmAgentsCommand = _reflection.GeneratedProtocolMessageType('ConfirmAgentsCommand', (_message.Message,), {
  'DESCRIPTOR' : _CONFIRMAGENTSCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.ConfirmAgentsCommand)
  })
_sym_db.RegisterMessage(ConfirmAgentsCommand)

AgentIdHitCountPair = _reflection.GeneratedProtocolMessageType('AgentIdHitCountPair', (_message.Message,), {
  'DESCRIPTOR' : _AGENTIDHITCOUNTPAIR,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.AgentIdHitCountPair)
  })
_sym_db.RegisterMessage(AgentIdHitCountPair)

HitCountUpdateMessage = _reflection.GeneratedProtocolMessageType('HitCountUpdateMessage', (_message.Message,), {
  'DESCRIPTOR' : _HITCOUNTUPDATEMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.HitCountUpdateMessage)
  })
_sym_db.RegisterMessage(HitCountUpdateMessage)

C2cRpcRequest = _reflection.GeneratedProtocolMessageType('C2cRpcRequest', (_message.Message,), {
  'DESCRIPTOR' : _C2CRPCREQUEST,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.C2cRpcRequest)
  })
_sym_db.RegisterMessage(C2cRpcRequest)

C2cRpcResponse = _reflection.GeneratedProtocolMessageType('C2cRpcResponse', (_message.Message,), {
  'DESCRIPTOR' : _C2CRPCRESPONSE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.C2cRpcResponse)
  })
_sym_db.RegisterMessage(C2cRpcResponse)

StartDatastoreConnectivityTestCommand = _reflection.GeneratedProtocolMessageType('StartDatastoreConnectivityTestCommand', (_message.Message,), {
  'DESCRIPTOR' : _STARTDATASTORECONNECTIVITYTESTCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.StartDatastoreConnectivityTestCommand)
  })
_sym_db.RegisterMessage(StartDatastoreConnectivityTestCommand)

DatastoreConnectivityTestC2cResponse = _reflection.GeneratedProtocolMessageType('DatastoreConnectivityTestC2cResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATASTORECONNECTIVITYTESTC2CRESPONSE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.DatastoreConnectivityTestC2cResponse)
  })
_sym_db.RegisterMessage(DatastoreConnectivityTestC2cResponse)

PingDatastoreCommand = _reflection.GeneratedProtocolMessageType('PingDatastoreCommand', (_message.Message,), {
  'DESCRIPTOR' : _PINGDATASTORECOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.PingDatastoreCommand)
  })
_sym_db.RegisterMessage(PingDatastoreCommand)

DatastoreInformation = _reflection.GeneratedProtocolMessageType('DatastoreInformation', (_message.Message,), {
  'DESCRIPTOR' : _DATASTOREINFORMATION,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.DatastoreInformation)
  })
_sym_db.RegisterMessage(DatastoreInformation)


DESCRIPTOR._options = None
_LOGMESSAGE.fields_by_name['formatted_message']._options = None
_LOGMESSAGE.fields_by_name['legacy_arguments']._options = None
_CONTROLLERLOGMESSAGE_METADATAENTRY._options = None
_CONTROLLERLOGMESSAGE_METADATAJSONVALUESENTRY._options = None
_AUGREPORTMESSAGE_STRINGSCACHEENTRY._options = None
_INITIALAUGSCOMMAND_SDKCONFIGURATIONENTRY._options = None
# @@protoc_insertion_point(module_scope)
