# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x61gent_info.proto\x12\x0b\x63om.rookout\"\xa6\x01\n\x0eSCMInformation\x12\x0e\n\x06\x63ommit\x18\x01 \x01(\t\x12\x0e\n\x06origin\x18\x02 \x01(\t\x12\x37\n\x07sources\x18\x04 \x03(\x0b\x32&.com.rookout.SCMInformation.SourceInfo\x1a\x35\n\nSourceInfo\x12\x17\n\x0fremoteOriginUrl\x18\x01 \x01(\t\x12\x0e\n\x06\x63ommit\x18\x02 \x01(\tJ\x04\x08\x03\x10\x04\"K\n\x12NetworkInformation\x12\x0f\n\x07ip_addr\x18\x01 \x01(\t\x12\x0f\n\x07network\x18\x02 \x01(\t\x12\x13\n\x0b\x65xternal_ip\x18\x03 \x01(\t\"c\n\x11SystemInformation\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\n\n\x02os\x18\x02 \x01(\t\x12\x12\n\nos_version\x18\x03 \x01(\t\x12\x0e\n\x06\x64istro\x18\x04 \x01(\t\x12\x0c\n\x04\x61rch\x18\x05 \x01(\t\"5\n\x12VersionInformation\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x0e\n\x06\x63ommit\x18\x02 \x01(\t\"I\n\x13PlatformInformation\x12\x10\n\x08platform\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0f\n\x07variant\x18\x03 \x01(\t\"\xd1\x03\n\x10\x41gentInformation\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\x12\x30\n\x07version\x18\x02 \x01(\x0b\x32\x1f.com.rookout.VersionInformation\x12\x30\n\x07network\x18\x03 \x01(\x0b\x32\x1f.com.rookout.NetworkInformation\x12.\n\x06system\x18\x04 \x01(\x0b\x32\x1e.com.rookout.SystemInformation\x12\x32\n\x08platform\x18\x05 \x01(\x0b\x32 .com.rookout.PlatformInformation\x12\x12\n\nexecutable\x18\x06 \x01(\t\x12\x19\n\x11\x63ommand_arguments\x18\x07 \x03(\t\x12\x12\n\nprocess_id\x18\x08 \x01(\r\x12\x39\n\x06labels\x18\t \x03(\x0b\x32).com.rookout.AgentInformation.LabelsEntry\x12(\n\x03scm\x18\n \x01(\x0b\x32\x1b.com.rookout.SCMInformation\x12\x0c\n\x04tags\x18\x0b \x03(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"F\n\x15\x41gentInformationArray\x12-\n\x06\x61gents\x18\x01 \x03(\x0b\x32\x1d.com.rookout.AgentInformationBO\n\x19\x63om.rookout.rook.protobufZ2github.com/Rookout/management/pkg/protos/protobuf2b\x06proto3')



_SCMINFORMATION = DESCRIPTOR.message_types_by_name['SCMInformation']
_SCMINFORMATION_SOURCEINFO = _SCMINFORMATION.nested_types_by_name['SourceInfo']
_NETWORKINFORMATION = DESCRIPTOR.message_types_by_name['NetworkInformation']
_SYSTEMINFORMATION = DESCRIPTOR.message_types_by_name['SystemInformation']
_VERSIONINFORMATION = DESCRIPTOR.message_types_by_name['VersionInformation']
_PLATFORMINFORMATION = DESCRIPTOR.message_types_by_name['PlatformInformation']
_AGENTINFORMATION = DESCRIPTOR.message_types_by_name['AgentInformation']
_AGENTINFORMATION_LABELSENTRY = _AGENTINFORMATION.nested_types_by_name['LabelsEntry']
_AGENTINFORMATIONARRAY = DESCRIPTOR.message_types_by_name['AgentInformationArray']
SCMInformation = _reflection.GeneratedProtocolMessageType('SCMInformation', (_message.Message,), {

  'SourceInfo' : _reflection.GeneratedProtocolMessageType('SourceInfo', (_message.Message,), {
    'DESCRIPTOR' : _SCMINFORMATION_SOURCEINFO,
    '__module__' : 'agent_info_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.SCMInformation.SourceInfo)
    })
  ,
  'DESCRIPTOR' : _SCMINFORMATION,
  '__module__' : 'agent_info_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.SCMInformation)
  })
_sym_db.RegisterMessage(SCMInformation)
_sym_db.RegisterMessage(SCMInformation.SourceInfo)

NetworkInformation = _reflection.GeneratedProtocolMessageType('NetworkInformation', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKINFORMATION,
  '__module__' : 'agent_info_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.NetworkInformation)
  })
_sym_db.RegisterMessage(NetworkInformation)

SystemInformation = _reflection.GeneratedProtocolMessageType('SystemInformation', (_message.Message,), {
  'DESCRIPTOR' : _SYSTEMINFORMATION,
  '__module__' : 'agent_info_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.SystemInformation)
  })
_sym_db.RegisterMessage(SystemInformation)

VersionInformation = _reflection.GeneratedProtocolMessageType('VersionInformation', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONINFORMATION,
  '__module__' : 'agent_info_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.VersionInformation)
  })
_sym_db.RegisterMessage(VersionInformation)

PlatformInformation = _reflection.GeneratedProtocolMessageType('PlatformInformation', (_message.Message,), {
  'DESCRIPTOR' : _PLATFORMINFORMATION,
  '__module__' : 'agent_info_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.PlatformInformation)
  })
_sym_db.RegisterMessage(PlatformInformation)

AgentInformation = _reflection.GeneratedProtocolMessageType('AgentInformation', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _AGENTINFORMATION_LABELSENTRY,
    '__module__' : 'agent_info_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.AgentInformation.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _AGENTINFORMATION,
  '__module__' : 'agent_info_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.AgentInformation)
  })
_sym_db.RegisterMessage(AgentInformation)
_sym_db.RegisterMessage(AgentInformation.LabelsEntry)

AgentInformationArray = _reflection.GeneratedProtocolMessageType('AgentInformationArray', (_message.Message,), {
  'DESCRIPTOR' : _AGENTINFORMATIONARRAY,
  '__module__' : 'agent_info_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.AgentInformationArray)
  })
_sym_db.RegisterMessage(AgentInformationArray)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.rookout.rook.protobufZ2github.com/Rookout/management/pkg/protos/protobuf2'
  _AGENTINFORMATION_LABELSENTRY._options = None
  _AGENTINFORMATION_LABELSENTRY._serialized_options = b'8\001'
  _SCMINFORMATION._serialized_start=34
  _SCMINFORMATION._serialized_end=200
  _SCMINFORMATION_SOURCEINFO._serialized_start=141
  _SCMINFORMATION_SOURCEINFO._serialized_end=194
  _NETWORKINFORMATION._serialized_start=202
  _NETWORKINFORMATION._serialized_end=277
  _SYSTEMINFORMATION._serialized_start=279
  _SYSTEMINFORMATION._serialized_end=378
  _VERSIONINFORMATION._serialized_start=380
  _VERSIONINFORMATION._serialized_end=433
  _PLATFORMINFORMATION._serialized_start=435
  _PLATFORMINFORMATION._serialized_end=508
  _AGENTINFORMATION._serialized_start=511
  _AGENTINFORMATION._serialized_end=976
  _AGENTINFORMATION_LABELSENTRY._serialized_start=931
  _AGENTINFORMATION_LABELSENTRY._serialized_end=976
  _AGENTINFORMATIONARRAY._serialized_start=978
  _AGENTINFORMATIONARRAY._serialized_end=1048
# @@protoc_insertion_point(module_scope)
