# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: variant2.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import variant_pb2 as variant__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0evariant2.proto\x12\x0b\x63om.rookout\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\rvariant.proto\"\xa0\x01\n\x06\x45rror2\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12)\n\nparameters\x18\x03 \x01(\x0b\x32\x15.com.rookout.Variant2\x12\"\n\x03\x65xc\x18\x04 \x01(\x0b\x32\x15.com.rookout.Variant2\x12(\n\ttraceback\x18\x05 \x01(\x0b\x32\x15.com.rookout.Variant2\"\xe1\x04\n\x08Variant2\x12\x1e\n\x16variant_type_max_depth\x18\x01 \x01(\r\x12$\n\x1coriginal_type_index_in_cache\x18\x02 \x01(\r\x12 \n\x18\x61ttribute_names_in_cache\x18\x03 \x03(\r\x12/\n\x10\x61ttribute_values\x18\x04 \x03(\x0b\x32\x15.com.rookout.Variant2\x12\x15\n\roriginal_size\x18\x05 \x01(\r\x12\x12\n\nlong_value\x18\x06 \x01(\x03\x12\x1c\n\x14\x62ytes_index_in_cache\x18\x07 \x01(\r\x12.\n\x0f\x63ollection_keys\x18\x08 \x03(\x0b\x32\x15.com.rookout.Variant2\x12\x30\n\x11\x63ollection_values\x18\t \x03(\x0b\x32\x15.com.rookout.Variant2\x12\x14\n\x0c\x64ouble_value\x18\n \x01(\x01\x12\x34\n\x0b\x63ode_values\x18\x0b \x03(\x0b\x32\x1f.com.rookout.Variant.CodeObject\x12.\n\ntime_value\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x0b\x65rror_value\x18\x10 \x01(\x0b\x32\x13.com.rookout.Error2\x12\x33\n\rcomplex_value\x18\x11 \x01(\x0b\x32\x1c.com.rookout.Variant.Complex\x12\x36\n\x08livetail\x18\x12 \x01(\x0b\x32$.com.rookout.Variant.LiveTailMessageBO\n\x19\x63om.rookout.rook.protobufZ2github.com/Rookout/management/pkg/protos/protobuf2b\x06proto3')



_ERROR2 = DESCRIPTOR.message_types_by_name['Error2']
_VARIANT2 = DESCRIPTOR.message_types_by_name['Variant2']
Error2 = _reflection.GeneratedProtocolMessageType('Error2', (_message.Message,), {
  'DESCRIPTOR' : _ERROR2,
  '__module__' : 'variant2_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.Error2)
  })
_sym_db.RegisterMessage(Error2)

Variant2 = _reflection.GeneratedProtocolMessageType('Variant2', (_message.Message,), {
  'DESCRIPTOR' : _VARIANT2,
  '__module__' : 'variant2_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.Variant2)
  })
_sym_db.RegisterMessage(Variant2)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.rookout.rook.protobufZ2github.com/Rookout/management/pkg/protos/protobuf2'
  _ERROR2._serialized_start=80
  _ERROR2._serialized_end=240
  _VARIANT2._serialized_start=243
  _VARIANT2._serialized_end=852
# @@protoc_insertion_point(module_scope)
