# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: variant.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rvariant.proto\x12\x0b\x63om.rookout\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9c\x01\n\x05\x45rror\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12(\n\nparameters\x18\x03 \x01(\x0b\x32\x14.com.rookout.Variant\x12!\n\x03\x65xc\x18\x04 \x01(\x0b\x32\x14.com.rookout.Variant\x12\'\n\ttraceback\x18\x05 \x01(\x0b\x32\x14.com.rookout.Variant\"\xf5\x15\n\x07Variant\x12/\n\x0cvariant_type\x18\x01 \x01(\x0e\x32\x19.com.rookout.Variant.Type\x12\x15\n\roriginal_type\x18\x02 \x01(\t\x12\x33\n\nattributes\x18\x03 \x03(\x0b\x32\x1f.com.rookout.Variant.NamedValue\x12\x11\n\tmax_depth\x18\x04 \x01(\x08\x12$\n\x1coriginal_type_index_in_cache\x18\x05 \x01(\r\x12\x13\n\tint_value\x18\x0b \x01(\x05H\x00\x12\x14\n\nlong_value\x18\x0c \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\r \x01(\x01H\x00\x12\x33\n\x0c\x62inary_value\x18\x0e \x01(\x0b\x32\x1b.com.rookout.Variant.BinaryH\x00\x12\x33\n\x0cstring_value\x18\x0f \x01(\x0b\x32\x1b.com.rookout.Variant.StringH\x00\x12/\n\nlist_value\x18\x10 \x01(\x0b\x32\x19.com.rookout.Variant.ListH\x00\x12-\n\tmap_value\x18\x11 \x01(\x0b\x32\x18.com.rookout.Variant.MapH\x00\x12\x39\n\x0fnamespace_value\x18\x13 \x01(\x0b\x32\x1e.com.rookout.Variant.NamespaceH\x00\x12)\n\x0b\x65rror_value\x18\x14 \x01(\x0b\x32\x12.com.rookout.ErrorH\x00\x12>\n\rmessage_value\x18\x17 \x01(\x0b\x32%.com.rookout.Variant.FormattedMessageH\x00\x12\x30\n\ntime_value\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x35\n\ncode_value\x18\x1a \x01(\x0b\x32\x1f.com.rookout.Variant.CodeObjectH\x00\x12\x38\n\x0flarge_int_value\x18\x1b \x01(\x0b\x32\x1d.com.rookout.Variant.LargeIntH\x00\x12\x35\n\rcomplex_value\x18\x1c \x01(\x0b\x32\x1c.com.rookout.Variant.ComplexH\x00\x12\x36\n\nenum_value\x18\x1f \x01(\x0b\x32 .com.rookout.Variant.EnumerationH\x00\x12\x33\n\ttraceback\x18  \x01(\x0b\x32\x1e.com.rookout.Variant.TracebackH\x00\x12\x38\n\x08livetail\x18! \x01(\x0b\x32$.com.rookout.Variant.LiveTailMessageH\x00\x1a?\n\nNamedValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.com.rookout.Variant\x1a.\n\x06\x42inary\x12\x15\n\roriginal_size\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x0c\x1aL\n\x06String\x12\x15\n\roriginal_size\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\x12\x1c\n\x14value_index_in_cache\x18\x03 \x01(\r\x1aQ\n\x04List\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x15\n\roriginal_size\x18\x02 \x01(\x05\x12$\n\x06values\x18\x03 \x03(\x0b\x32\x14.com.rookout.Variant\x1aQ\n\x04Pair\x12#\n\x05\x66irst\x18\x01 \x01(\x0b\x32\x14.com.rookout.Variant\x12$\n\x06second\x18\x02 \x01(\x0b\x32\x14.com.rookout.Variant\x1a\x46\n\x03Map\x12\x15\n\roriginal_size\x18\x01 \x01(\x05\x12(\n\x05pairs\x18\x02 \x03(\x0b\x32\x19.com.rookout.Variant.Pair\x1a@\n\tNamespace\x12\x33\n\nattributes\x18\x01 \x03(\x0b\x32\x1f.com.rookout.Variant.NamedValue\x1a#\n\x10\x46ormattedMessage\x12\x0f\n\x07message\x18\x01 \x01(\t\x1a\xa9\x01\n\nCodeObject\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06module\x18\x02 \x01(\t\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\x12\x0e\n\x06lineno\x18\x04 \x01(\r\x12\x1b\n\x13name_index_in_cache\x18\x05 \x01(\r\x12\x1d\n\x15module_index_in_cache\x18\x06 \x01(\r\x12\x1f\n\x17\x66ilename_index_in_cache\x18\x07 \x01(\r\x1a\x19\n\x08LargeInt\x12\r\n\x05value\x18\x01 \x01(\t\x1a*\n\x07\x43omplex\x12\x0c\n\x04real\x18\x01 \x01(\x01\x12\x11\n\timaginary\x18\x02 \x01(\x01\x1aM\n\x0b\x45numeration\x12\x14\n\x0cstring_value\x18\x01 \x01(\t\x12\x15\n\rordinal_value\x18\x02 \x01(\x05\x12\x11\n\ttype_name\x18\x03 \x01(\t\x1a?\n\tTraceback\x12\x32\n\tlocations\x18\x01 \x03(\x0b\x32\x1f.com.rookout.Variant.CodeObject\x1a\xc5\x02\n\x0fLiveTailMessage\x12\x12\n\nlevel_name\x18\x01 \x01(\t\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x19\n\x11\x66ormatted_message\x18\x03 \x01(\t\x12\x0c\n\x04time\x18\x04 \x01(\x01\x12\x10\n\x08\x66ilename\x18\x05 \x01(\t\x12\x0e\n\x06lineno\x18\x06 \x01(\x05\x12\x10\n\x08\x66unction\x18\x07 \x01(\t\x12\x0e\n\x06module\x18\x08 \x01(\t\x12\x11\n\tthread_id\x18\t \x01(\x03\x12\x13\n\x0bthread_name\x18\n \x01(\t\x12I\n\x0blog_context\x18\x0b \x03(\x0b\x32\x34.com.rookout.Variant.LiveTailMessage.LogContextEntry\x1a\x31\n\x0fLogContextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x04\n\x04Type\x12\x10\n\x0cVARIANT_NONE\x10\x00\x12\x0f\n\x0bVARIANT_INT\x10\x01\x12\x10\n\x0cVARIANT_LONG\x10\x02\x12\x12\n\x0eVARIANT_DOUBLE\x10\x03\x12\x12\n\x0eVARIANT_BINARY\x10\x04\x12\x12\n\x0eVARIANT_STRING\x10\x05\x12\x10\n\x0cVARIANT_LIST\x10\x06\x12\x0f\n\x0bVARIANT_MAP\x10\x07\x12\x12\n\x0eVARIANT_OBJECT\x10\x08\x12\x15\n\x11VARIANT_NAMESPACE\x10\t\x12\x11\n\rVARIANT_ERROR\x10\n\x12\x19\n\x15VARIANT_NOT_SUPPORTED\x10\x0b\x12\x15\n\x11VARIANT_MAX_DEPTH\x10\x0c\x12\x1d\n\x19VARIANT_FORMATTED_MESSAGE\x10\r\x12\x10\n\x0cVARIANT_TIME\x10\x0e\x12\x19\n\x15VARIANT_UKNOWN_OBJECT\x10\x0f\x12\x17\n\x13VARIANT_CODE_OBJECT\x10\x10\x12\x15\n\x11VARIANT_LARGE_INT\x10\x11\x12\x13\n\x0fVARIANT_COMPLEX\x10\x12\x12\x15\n\x11VARIANT_UNDEFINED\x10\x13\x12\x13\n\x0fVARIANT_DYNAMIC\x10\x14\x12\x10\n\x0cVARIANT_ENUM\x10\x15\x12\x15\n\x11VARIANT_TRACEBACK\x10\x16\x12\x14\n\x10VARIANT_LIVETAIL\x10\x17\x12\x0f\n\x0bVARIANT_SET\x10\x18\x42\x07\n\x05valueBO\n\x19\x63om.rookout.rook.protobufZ2github.com/Rookout/management/pkg/protos/protobuf2b\x06proto3')



_ERROR = DESCRIPTOR.message_types_by_name['Error']
_VARIANT = DESCRIPTOR.message_types_by_name['Variant']
_VARIANT_NAMEDVALUE = _VARIANT.nested_types_by_name['NamedValue']
_VARIANT_BINARY = _VARIANT.nested_types_by_name['Binary']
_VARIANT_STRING = _VARIANT.nested_types_by_name['String']
_VARIANT_LIST = _VARIANT.nested_types_by_name['List']
_VARIANT_PAIR = _VARIANT.nested_types_by_name['Pair']
_VARIANT_MAP = _VARIANT.nested_types_by_name['Map']
_VARIANT_NAMESPACE = _VARIANT.nested_types_by_name['Namespace']
_VARIANT_FORMATTEDMESSAGE = _VARIANT.nested_types_by_name['FormattedMessage']
_VARIANT_CODEOBJECT = _VARIANT.nested_types_by_name['CodeObject']
_VARIANT_LARGEINT = _VARIANT.nested_types_by_name['LargeInt']
_VARIANT_COMPLEX = _VARIANT.nested_types_by_name['Complex']
_VARIANT_ENUMERATION = _VARIANT.nested_types_by_name['Enumeration']
_VARIANT_TRACEBACK = _VARIANT.nested_types_by_name['Traceback']
_VARIANT_LIVETAILMESSAGE = _VARIANT.nested_types_by_name['LiveTailMessage']
_VARIANT_LIVETAILMESSAGE_LOGCONTEXTENTRY = _VARIANT_LIVETAILMESSAGE.nested_types_by_name['LogContextEntry']
_VARIANT_TYPE = _VARIANT.enum_types_by_name['Type']
Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
  'DESCRIPTOR' : _ERROR,
  '__module__' : 'variant_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.Error)
  })
_sym_db.RegisterMessage(Error)

Variant = _reflection.GeneratedProtocolMessageType('Variant', (_message.Message,), {

  'NamedValue' : _reflection.GeneratedProtocolMessageType('NamedValue', (_message.Message,), {
    'DESCRIPTOR' : _VARIANT_NAMEDVALUE,
    '__module__' : 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.NamedValue)
    })
  ,

  'Binary' : _reflection.GeneratedProtocolMessageType('Binary', (_message.Message,), {
    'DESCRIPTOR' : _VARIANT_BINARY,
    '__module__' : 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.Binary)
    })
  ,

  'String' : _reflection.GeneratedProtocolMessageType('String', (_message.Message,), {
    'DESCRIPTOR' : _VARIANT_STRING,
    '__module__' : 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.String)
    })
  ,

  'List' : _reflection.GeneratedProtocolMessageType('List', (_message.Message,), {
    'DESCRIPTOR' : _VARIANT_LIST,
    '__module__' : 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.List)
    })
  ,

  'Pair' : _reflection.GeneratedProtocolMessageType('Pair', (_message.Message,), {
    'DESCRIPTOR' : _VARIANT_PAIR,
    '__module__' : 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.Pair)
    })
  ,

  'Map' : _reflection.GeneratedProtocolMessageType('Map', (_message.Message,), {
    'DESCRIPTOR' : _VARIANT_MAP,
    '__module__' : 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.Map)
    })
  ,

  'Namespace' : _reflection.GeneratedProtocolMessageType('Namespace', (_message.Message,), {
    'DESCRIPTOR' : _VARIANT_NAMESPACE,
    '__module__' : 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.Namespace)
    })
  ,

  'FormattedMessage' : _reflection.GeneratedProtocolMessageType('FormattedMessage', (_message.Message,), {
    'DESCRIPTOR' : _VARIANT_FORMATTEDMESSAGE,
    '__module__' : 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.FormattedMessage)
    })
  ,

  'CodeObject' : _reflection.GeneratedProtocolMessageType('CodeObject', (_message.Message,), {
    'DESCRIPTOR' : _VARIANT_CODEOBJECT,
    '__module__' : 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.CodeObject)
    })
  ,

  'LargeInt' : _reflection.GeneratedProtocolMessageType('LargeInt', (_message.Message,), {
    'DESCRIPTOR' : _VARIANT_LARGEINT,
    '__module__' : 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.LargeInt)
    })
  ,

  'Complex' : _reflection.GeneratedProtocolMessageType('Complex', (_message.Message,), {
    'DESCRIPTOR' : _VARIANT_COMPLEX,
    '__module__' : 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.Complex)
    })
  ,

  'Enumeration' : _reflection.GeneratedProtocolMessageType('Enumeration', (_message.Message,), {
    'DESCRIPTOR' : _VARIANT_ENUMERATION,
    '__module__' : 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.Enumeration)
    })
  ,

  'Traceback' : _reflection.GeneratedProtocolMessageType('Traceback', (_message.Message,), {
    'DESCRIPTOR' : _VARIANT_TRACEBACK,
    '__module__' : 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.Traceback)
    })
  ,

  'LiveTailMessage' : _reflection.GeneratedProtocolMessageType('LiveTailMessage', (_message.Message,), {

    'LogContextEntry' : _reflection.GeneratedProtocolMessageType('LogContextEntry', (_message.Message,), {
      'DESCRIPTOR' : _VARIANT_LIVETAILMESSAGE_LOGCONTEXTENTRY,
      '__module__' : 'variant_pb2'
      # @@protoc_insertion_point(class_scope:com.rookout.Variant.LiveTailMessage.LogContextEntry)
      })
    ,
    'DESCRIPTOR' : _VARIANT_LIVETAILMESSAGE,
    '__module__' : 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.LiveTailMessage)
    })
  ,
  'DESCRIPTOR' : _VARIANT,
  '__module__' : 'variant_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.Variant)
  })
_sym_db.RegisterMessage(Variant)
_sym_db.RegisterMessage(Variant.NamedValue)
_sym_db.RegisterMessage(Variant.Binary)
_sym_db.RegisterMessage(Variant.String)
_sym_db.RegisterMessage(Variant.List)
_sym_db.RegisterMessage(Variant.Pair)
_sym_db.RegisterMessage(Variant.Map)
_sym_db.RegisterMessage(Variant.Namespace)
_sym_db.RegisterMessage(Variant.FormattedMessage)
_sym_db.RegisterMessage(Variant.CodeObject)
_sym_db.RegisterMessage(Variant.LargeInt)
_sym_db.RegisterMessage(Variant.Complex)
_sym_db.RegisterMessage(Variant.Enumeration)
_sym_db.RegisterMessage(Variant.Traceback)
_sym_db.RegisterMessage(Variant.LiveTailMessage)
_sym_db.RegisterMessage(Variant.LiveTailMessage.LogContextEntry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.rookout.rook.protobufZ2github.com/Rookout/management/pkg/protos/protobuf2'
  _VARIANT_LIVETAILMESSAGE_LOGCONTEXTENTRY._options = None
  _VARIANT_LIVETAILMESSAGE_LOGCONTEXTENTRY._serialized_options = b'8\001'
  _ERROR._serialized_start=64
  _ERROR._serialized_end=220
  _VARIANT._serialized_start=223
  _VARIANT._serialized_end=3028
  _VARIANT_NAMEDVALUE._serialized_start=1236
  _VARIANT_NAMEDVALUE._serialized_end=1299
  _VARIANT_BINARY._serialized_start=1301
  _VARIANT_BINARY._serialized_end=1347
  _VARIANT_STRING._serialized_start=1349
  _VARIANT_STRING._serialized_end=1425
  _VARIANT_LIST._serialized_start=1427
  _VARIANT_LIST._serialized_end=1508
  _VARIANT_PAIR._serialized_start=1510
  _VARIANT_PAIR._serialized_end=1591
  _VARIANT_MAP._serialized_start=1593
  _VARIANT_MAP._serialized_end=1663
  _VARIANT_NAMESPACE._serialized_start=1665
  _VARIANT_NAMESPACE._serialized_end=1729
  _VARIANT_FORMATTEDMESSAGE._serialized_start=1731
  _VARIANT_FORMATTEDMESSAGE._serialized_end=1766
  _VARIANT_CODEOBJECT._serialized_start=1769
  _VARIANT_CODEOBJECT._serialized_end=1938
  _VARIANT_LARGEINT._serialized_start=1940
  _VARIANT_LARGEINT._serialized_end=1965
  _VARIANT_COMPLEX._serialized_start=1967
  _VARIANT_COMPLEX._serialized_end=2009
  _VARIANT_ENUMERATION._serialized_start=2011
  _VARIANT_ENUMERATION._serialized_end=2088
  _VARIANT_TRACEBACK._serialized_start=2090
  _VARIANT_TRACEBACK._serialized_end=2153
  _VARIANT_LIVETAILMESSAGE._serialized_start=2156
  _VARIANT_LIVETAILMESSAGE._serialized_end=2481
  _VARIANT_LIVETAILMESSAGE_LOGCONTEXTENTRY._serialized_start=2432
  _VARIANT_LIVETAILMESSAGE_LOGCONTEXTENTRY._serialized_end=2481
  _VARIANT_TYPE._serialized_start=2484
  _VARIANT_TYPE._serialized_end=3019
# @@protoc_insertion_point(module_scope)
