# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import variant_pb2 as variant__pb2
from . import variant2_pb2 as variant2__pb2
from . import agent_info_pb2 as agent__info__pb2
from . import controller_info_pb2 as controller__info__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0emessages.proto\x12\x0b\x63om.rookout\x1a\rvariant.proto\x1a\x0evariant2.proto\x1a\x10\x61gent_info.proto\x1a\x15\x63ontroller_info.proto\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"D\n\x0fNewAgentMessage\x12\x31\n\nagent_info\x18\x01 \x01(\x0b\x32\x1d.com.rookout.AgentInformation\">\n\nStackFrame\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0c\n\x04line\x18\x02 \x01(\r\x12\x10\n\x08\x66unction\x18\x03 \x01(\t\"5\n\nStackTrace\x12\'\n\x06\x66rames\x18\x01 \x03(\x0b\x32\x17.com.rookout.StackFrame\"~\n\tException\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12&\n\x08instance\x18\x03 \x01(\x0b\x32\x14.com.rookout.Variant\x12*\n\ttraceback\x18\x04 \x01(\x0b\x32\x17.com.rookout.StackTrace\"\xe2\x03\n\nLogMessage\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x61gent_id\x18\x02 \x01(\t\x12/\n\x05level\x18\x03 \x01(\x0e\x32 .com.rookout.LogMessage.LogLevel\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12\x0c\n\x04line\x18\x05 \x01(\r\x12\x0c\n\x04text\x18\x06 \x01(\t\x12\'\n\targuments\x18\x07 \x03(\x0b\x32\x14.com.rookout.Variant\x12)\n\texception\x18\x08 \x01(\x0b\x32\x16.com.rookout.Exception\x12\x1d\n\x11\x66ormatted_message\x18\t \x01(\tB\x02\x18\x01\x12\x32\n\x10legacy_arguments\x18\n \x01(\x0b\x32\x14.com.rookout.VariantB\x02\x18\x01\x12\x12\n\nclass_name\x18\x0b \x01(\t\x12\x13\n\x0bmethod_name\x18\x0c \x01(\t\x12\x15\n\rcontroller_id\x18\r \x01(\t\"M\n\x08LogLevel\x12\t\n\x05TRACE\x10\x00\x12\t\n\x05\x44\x45\x42UG\x10\x01\x12\x08\n\x04INFO\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\t\n\x05\x46\x41TAL\x10\x05\"\xa3\x05\n\x14\x43ontrollerLogMessage\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x05level\x18\x02 \x01(\x0e\x32*.com.rookout.ControllerLogMessage.LogLevel\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\x12\x0c\n\x04line\x18\x04 \x01(\r\x12\x0c\n\x04text\x18\x05 \x01(\t\x12\x12\n\nclass_name\x18\x06 \x01(\t\x12\x13\n\x0bmethod_name\x18\x07 \x01(\t\x12\x15\n\rcontroller_id\x18\x08 \x01(\t\x12\x36\n\x05\x65rror\x18\t \x01(\x0b\x32\'.com.rookout.ControllerLogMessage.Error\x12\x41\n\x08metadata\x18\n \x03(\x0b\x32/.com.rookout.ControllerLogMessage.MetadataEntry\x12U\n\x12metadataJSONValues\x18\x0b \x03(\x0b\x32\x39.com.rookout.ControllerLogMessage.MetadataJSONValuesEntry\x1a&\n\x05\x45rror\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x39\n\x17MetadataJSONValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"M\n\x08LogLevel\x12\t\n\x05TRACE\x10\x00\x12\t\n\x05\x44\x45\x42UG\x10\x01\x12\x08\n\x04INFO\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\t\n\x05\x46\x41TAL\x10\x05\"\x80\x01\n\x11RuleStatusMessage\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\x12\x0f\n\x07rule_id\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x03 \x01(\t\x12!\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x12.com.rookout.Error\x12\x15\n\rcontroller_id\x18\x05 \x01(\t\"\xf0\x02\n\x10\x41ugReportMessage\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61ug_id\x18\x02 \x01(\t\x12\'\n\targuments\x18\x03 \x01(\x0b\x32\x14.com.rookout.Variant\x12\x11\n\treport_id\x18\x04 \x01(\t\x12\x46\n\rstrings_cache\x18\x05 \x03(\x0b\x32/.com.rookout.AugReportMessage.StringsCacheEntry\x12\x1c\n\x14\x62uffer_cache_buffers\x18\x06 \x03(\x0c\x12\x1c\n\x14\x62uffer_cache_indexes\x18\x07 \x03(\r\x12)\n\narguments2\x18\x08 \x01(\x0b\x32\x15.com.rookout.Variant2\x12\x1a\n\x12reverse_list_order\x18\t \x01(\x08\x1a\x33\n\x11StringsCacheEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\"e\n\x07UserMsg\x12\x31\n\naug_report\x18\x01 \x01(\x0b\x32\x1d.com.rookout.AugReportMessage\x12\x11\n\treport_id\x18\x02 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x03 \x01(\t\"!\n\rAddAugCommand\x12\x10\n\x08\x61ug_json\x18\x01 \x01(\t\"\xad\x01\n\x12InitialAugsCommand\x12\x0c\n\x04\x61ugs\x18\x01 \x03(\t\x12P\n\x11sdk_configuration\x18\x02 \x03(\x0b\x32\x35.com.rookout.InitialAugsCommand.SdkConfigurationEntry\x1a\x37\n\x15SdkConfigurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\"\n\x10RemoveAugCommand\x12\x0e\n\x06\x61ug_id\x18\x01 \x01(\t\"\x15\n\x13InitFinishedMessage\"\x12\n\x10\x43learAugsCommand\"\x1c\n\x0bPingMessage\x12\r\n\x05value\x18\x01 \x01(\x05\"\x1f\n\x0c\x45rrorMessage\x12\x0f\n\x07message\x18\x01 \x01(\t\"e\n\x0e\x43\x32\x43InitMessage\x12:\n\x0e\x63ontrollerInfo\x18\x01 \x01(\x0b\x32\".com.rookout.ControllerInformation\x12\x17\n\x0f\x63onnectedAgents\x18\x02 \x03(\t\"U\n\x16\x44\x61taOnPremTokenRequest\x12;\n\x0b\x61\x63\x63\x65ss_type\x18\x01 \x01(\x0e\x32&.com.rookout.DataOnPremTokenAccessType\"(\n\x17\x44\x61taOnPremTokenResponse\x12\r\n\x05token\x18\x01 \x01(\x0c\" \n\nAgentsList\x12\x12\n\nagents_ids\x18\x01 \x03(\t\"!\n\x0c\x41ssertAgents\x12\x11\n\tagent_ids\x18\x01 \x03(\t\"-\n\x17InvalidateAgentsCommand\x12\x12\n\nagents_ids\x18\x01 \x03(\t\"*\n\x14\x43onfirmAgentsCommand\x12\x12\n\nagents_ids\x18\x01 \x03(\t\":\n\x13\x41gentIdHitCountPair\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\x12\x11\n\thit_count\x18\x02 \x01(\r\"f\n\x15HitCountUpdateMessage\x12\x0e\n\x06\x61ug_id\x18\x01 \x01(\t\x12=\n\x13hitCountInformation\x18\x02 \x03(\x0b\x32 .com.rookout.AgentIdHitCountPair\"L\n\rC2cRpcRequest\x12\x14\n\x0crequest_uuid\x18\x01 \x01(\t\x12%\n\x07message\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"\\\n\x0e\x43\x32\x63RpcResponse\x12\x14\n\x0crequest_uuid\x18\x01 \x01(\t\x12%\n\x07message\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"w\n%StartDatastoreConnectivityTestCommand\x12\r\n\x05orgId\x18\x01 \x01(\t\x12\x14\n\x0c\x63ontrollerId\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61tastoreUrl\x18\x03 \x01(\t\x12\x13\n\x0bworkspaceId\x18\x04 \x01(\t\"{\n$DatastoreConnectivityTestC2cResponse\x12\x14\n\x0c\x63ontrollerId\x18\x01 \x01(\t\x12\x15\n\rTestMessageId\x18\x02 \x01(\t\x12\x11\n\tisSuccess\x18\x03 \x01(\x08\x12\x13\n\x0b\x65rrorString\x18\x04 \x01(\t\",\n\x14PingDatastoreCommand\x12\x14\n\x0c\x64\x61tastoreUrl\x18\x01 \x01(\t\"\xb3\x01\n\x14\x44\x61tastoreInformation\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x10\n\x08hostname\x18\x02 \x01(\t\x12\x14\n\x0cmachine_type\x18\x03 \x01(\t\x12\x0f\n\x07network\x18\x04 \x01(\t\x12\n\n\x02ip\x18\x05 \x01(\t\x12\n\n\x02os\x18\x06 \x01(\t\x12\x12\n\nos_release\x18\x07 \x01(\t\x12\x12\n\nos_version\x18\x08 \x01(\t\x12\x11\n\tos_string\x18\t \x01(\t*0\n\x19\x44\x61taOnPremTokenAccessType\x12\t\n\x05WRITE\x10\x00\x12\x08\n\x04READ\x10\x01\x42O\n\x19\x63om.rookout.rook.protobufZ2github.com/Rookout/management/pkg/protos/protobuf2b\x06proto3')

_DATAONPREMTOKENACCESSTYPE = DESCRIPTOR.enum_types_by_name['DataOnPremTokenAccessType']
DataOnPremTokenAccessType = enum_type_wrapper.EnumTypeWrapper(_DATAONPREMTOKENACCESSTYPE)
WRITE = 0
READ = 1


_NEWAGENTMESSAGE = DESCRIPTOR.message_types_by_name['NewAgentMessage']
_STACKFRAME = DESCRIPTOR.message_types_by_name['StackFrame']
_STACKTRACE = DESCRIPTOR.message_types_by_name['StackTrace']
_EXCEPTION = DESCRIPTOR.message_types_by_name['Exception']
_LOGMESSAGE = DESCRIPTOR.message_types_by_name['LogMessage']
_CONTROLLERLOGMESSAGE = DESCRIPTOR.message_types_by_name['ControllerLogMessage']
_CONTROLLERLOGMESSAGE_ERROR = _CONTROLLERLOGMESSAGE.nested_types_by_name['Error']
_CONTROLLERLOGMESSAGE_METADATAENTRY = _CONTROLLERLOGMESSAGE.nested_types_by_name['MetadataEntry']
_CONTROLLERLOGMESSAGE_METADATAJSONVALUESENTRY = _CONTROLLERLOGMESSAGE.nested_types_by_name['MetadataJSONValuesEntry']
_RULESTATUSMESSAGE = DESCRIPTOR.message_types_by_name['RuleStatusMessage']
_AUGREPORTMESSAGE = DESCRIPTOR.message_types_by_name['AugReportMessage']
_AUGREPORTMESSAGE_STRINGSCACHEENTRY = _AUGREPORTMESSAGE.nested_types_by_name['StringsCacheEntry']
_USERMSG = DESCRIPTOR.message_types_by_name['UserMsg']
_ADDAUGCOMMAND = DESCRIPTOR.message_types_by_name['AddAugCommand']
_INITIALAUGSCOMMAND = DESCRIPTOR.message_types_by_name['InitialAugsCommand']
_INITIALAUGSCOMMAND_SDKCONFIGURATIONENTRY = _INITIALAUGSCOMMAND.nested_types_by_name['SdkConfigurationEntry']
_REMOVEAUGCOMMAND = DESCRIPTOR.message_types_by_name['RemoveAugCommand']
_INITFINISHEDMESSAGE = DESCRIPTOR.message_types_by_name['InitFinishedMessage']
_CLEARAUGSCOMMAND = DESCRIPTOR.message_types_by_name['ClearAugsCommand']
_PINGMESSAGE = DESCRIPTOR.message_types_by_name['PingMessage']
_ERRORMESSAGE = DESCRIPTOR.message_types_by_name['ErrorMessage']
_C2CINITMESSAGE = DESCRIPTOR.message_types_by_name['C2CInitMessage']
_DATAONPREMTOKENREQUEST = DESCRIPTOR.message_types_by_name['DataOnPremTokenRequest']
_DATAONPREMTOKENRESPONSE = DESCRIPTOR.message_types_by_name['DataOnPremTokenResponse']
_AGENTSLIST = DESCRIPTOR.message_types_by_name['AgentsList']
_ASSERTAGENTS = DESCRIPTOR.message_types_by_name['AssertAgents']
_INVALIDATEAGENTSCOMMAND = DESCRIPTOR.message_types_by_name['InvalidateAgentsCommand']
_CONFIRMAGENTSCOMMAND = DESCRIPTOR.message_types_by_name['ConfirmAgentsCommand']
_AGENTIDHITCOUNTPAIR = DESCRIPTOR.message_types_by_name['AgentIdHitCountPair']
_HITCOUNTUPDATEMESSAGE = DESCRIPTOR.message_types_by_name['HitCountUpdateMessage']
_C2CRPCREQUEST = DESCRIPTOR.message_types_by_name['C2cRpcRequest']
_C2CRPCRESPONSE = DESCRIPTOR.message_types_by_name['C2cRpcResponse']
_STARTDATASTORECONNECTIVITYTESTCOMMAND = DESCRIPTOR.message_types_by_name['StartDatastoreConnectivityTestCommand']
_DATASTORECONNECTIVITYTESTC2CRESPONSE = DESCRIPTOR.message_types_by_name['DatastoreConnectivityTestC2cResponse']
_PINGDATASTORECOMMAND = DESCRIPTOR.message_types_by_name['PingDatastoreCommand']
_DATASTOREINFORMATION = DESCRIPTOR.message_types_by_name['DatastoreInformation']
_LOGMESSAGE_LOGLEVEL = _LOGMESSAGE.enum_types_by_name['LogLevel']
_CONTROLLERLOGMESSAGE_LOGLEVEL = _CONTROLLERLOGMESSAGE.enum_types_by_name['LogLevel']
NewAgentMessage = _reflection.GeneratedProtocolMessageType('NewAgentMessage', (_message.Message,), {
  'DESCRIPTOR' : _NEWAGENTMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.NewAgentMessage)
  })
_sym_db.RegisterMessage(NewAgentMessage)

StackFrame = _reflection.GeneratedProtocolMessageType('StackFrame', (_message.Message,), {
  'DESCRIPTOR' : _STACKFRAME,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.StackFrame)
  })
_sym_db.RegisterMessage(StackFrame)

StackTrace = _reflection.GeneratedProtocolMessageType('StackTrace', (_message.Message,), {
  'DESCRIPTOR' : _STACKTRACE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.StackTrace)
  })
_sym_db.RegisterMessage(StackTrace)

Exception = _reflection.GeneratedProtocolMessageType('Exception', (_message.Message,), {
  'DESCRIPTOR' : _EXCEPTION,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.Exception)
  })
_sym_db.RegisterMessage(Exception)

LogMessage = _reflection.GeneratedProtocolMessageType('LogMessage', (_message.Message,), {
  'DESCRIPTOR' : _LOGMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.LogMessage)
  })
_sym_db.RegisterMessage(LogMessage)

ControllerLogMessage = _reflection.GeneratedProtocolMessageType('ControllerLogMessage', (_message.Message,), {

  'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
    'DESCRIPTOR' : _CONTROLLERLOGMESSAGE_ERROR,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.ControllerLogMessage.Error)
    })
  ,

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTROLLERLOGMESSAGE_METADATAENTRY,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.ControllerLogMessage.MetadataEntry)
    })
  ,

  'MetadataJSONValuesEntry' : _reflection.GeneratedProtocolMessageType('MetadataJSONValuesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTROLLERLOGMESSAGE_METADATAJSONVALUESENTRY,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.ControllerLogMessage.MetadataJSONValuesEntry)
    })
  ,
  'DESCRIPTOR' : _CONTROLLERLOGMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.ControllerLogMessage)
  })
_sym_db.RegisterMessage(ControllerLogMessage)
_sym_db.RegisterMessage(ControllerLogMessage.Error)
_sym_db.RegisterMessage(ControllerLogMessage.MetadataEntry)
_sym_db.RegisterMessage(ControllerLogMessage.MetadataJSONValuesEntry)

RuleStatusMessage = _reflection.GeneratedProtocolMessageType('RuleStatusMessage', (_message.Message,), {
  'DESCRIPTOR' : _RULESTATUSMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.RuleStatusMessage)
  })
_sym_db.RegisterMessage(RuleStatusMessage)

AugReportMessage = _reflection.GeneratedProtocolMessageType('AugReportMessage', (_message.Message,), {

  'StringsCacheEntry' : _reflection.GeneratedProtocolMessageType('StringsCacheEntry', (_message.Message,), {
    'DESCRIPTOR' : _AUGREPORTMESSAGE_STRINGSCACHEENTRY,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.AugReportMessage.StringsCacheEntry)
    })
  ,
  'DESCRIPTOR' : _AUGREPORTMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.AugReportMessage)
  })
_sym_db.RegisterMessage(AugReportMessage)
_sym_db.RegisterMessage(AugReportMessage.StringsCacheEntry)

UserMsg = _reflection.GeneratedProtocolMessageType('UserMsg', (_message.Message,), {
  'DESCRIPTOR' : _USERMSG,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.UserMsg)
  })
_sym_db.RegisterMessage(UserMsg)

AddAugCommand = _reflection.GeneratedProtocolMessageType('AddAugCommand', (_message.Message,), {
  'DESCRIPTOR' : _ADDAUGCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.AddAugCommand)
  })
_sym_db.RegisterMessage(AddAugCommand)

InitialAugsCommand = _reflection.GeneratedProtocolMessageType('InitialAugsCommand', (_message.Message,), {

  'SdkConfigurationEntry' : _reflection.GeneratedProtocolMessageType('SdkConfigurationEntry', (_message.Message,), {
    'DESCRIPTOR' : _INITIALAUGSCOMMAND_SDKCONFIGURATIONENTRY,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.InitialAugsCommand.SdkConfigurationEntry)
    })
  ,
  'DESCRIPTOR' : _INITIALAUGSCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.InitialAugsCommand)
  })
_sym_db.RegisterMessage(InitialAugsCommand)
_sym_db.RegisterMessage(InitialAugsCommand.SdkConfigurationEntry)

RemoveAugCommand = _reflection.GeneratedProtocolMessageType('RemoveAugCommand', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEAUGCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.RemoveAugCommand)
  })
_sym_db.RegisterMessage(RemoveAugCommand)

InitFinishedMessage = _reflection.GeneratedProtocolMessageType('InitFinishedMessage', (_message.Message,), {
  'DESCRIPTOR' : _INITFINISHEDMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.InitFinishedMessage)
  })
_sym_db.RegisterMessage(InitFinishedMessage)

ClearAugsCommand = _reflection.GeneratedProtocolMessageType('ClearAugsCommand', (_message.Message,), {
  'DESCRIPTOR' : _CLEARAUGSCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.ClearAugsCommand)
  })
_sym_db.RegisterMessage(ClearAugsCommand)

PingMessage = _reflection.GeneratedProtocolMessageType('PingMessage', (_message.Message,), {
  'DESCRIPTOR' : _PINGMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.PingMessage)
  })
_sym_db.RegisterMessage(PingMessage)

ErrorMessage = _reflection.GeneratedProtocolMessageType('ErrorMessage', (_message.Message,), {
  'DESCRIPTOR' : _ERRORMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.ErrorMessage)
  })
_sym_db.RegisterMessage(ErrorMessage)

C2CInitMessage = _reflection.GeneratedProtocolMessageType('C2CInitMessage', (_message.Message,), {
  'DESCRIPTOR' : _C2CINITMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.C2CInitMessage)
  })
_sym_db.RegisterMessage(C2CInitMessage)

DataOnPremTokenRequest = _reflection.GeneratedProtocolMessageType('DataOnPremTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATAONPREMTOKENREQUEST,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.DataOnPremTokenRequest)
  })
_sym_db.RegisterMessage(DataOnPremTokenRequest)

DataOnPremTokenResponse = _reflection.GeneratedProtocolMessageType('DataOnPremTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATAONPREMTOKENRESPONSE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.DataOnPremTokenResponse)
  })
_sym_db.RegisterMessage(DataOnPremTokenResponse)

AgentsList = _reflection.GeneratedProtocolMessageType('AgentsList', (_message.Message,), {
  'DESCRIPTOR' : _AGENTSLIST,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.AgentsList)
  })
_sym_db.RegisterMessage(AgentsList)

AssertAgents = _reflection.GeneratedProtocolMessageType('AssertAgents', (_message.Message,), {
  'DESCRIPTOR' : _ASSERTAGENTS,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.AssertAgents)
  })
_sym_db.RegisterMessage(AssertAgents)

InvalidateAgentsCommand = _reflection.GeneratedProtocolMessageType('InvalidateAgentsCommand', (_message.Message,), {
  'DESCRIPTOR' : _INVALIDATEAGENTSCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.InvalidateAgentsCommand)
  })
_sym_db.RegisterMessage(InvalidateAgentsCommand)

ConfirmAgentsCommand = _reflection.GeneratedProtocolMessageType('ConfirmAgentsCommand', (_message.Message,), {
  'DESCRIPTOR' : _CONFIRMAGENTSCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.ConfirmAgentsCommand)
  })
_sym_db.RegisterMessage(ConfirmAgentsCommand)

AgentIdHitCountPair = _reflection.GeneratedProtocolMessageType('AgentIdHitCountPair', (_message.Message,), {
  'DESCRIPTOR' : _AGENTIDHITCOUNTPAIR,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.AgentIdHitCountPair)
  })
_sym_db.RegisterMessage(AgentIdHitCountPair)

HitCountUpdateMessage = _reflection.GeneratedProtocolMessageType('HitCountUpdateMessage', (_message.Message,), {
  'DESCRIPTOR' : _HITCOUNTUPDATEMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.HitCountUpdateMessage)
  })
_sym_db.RegisterMessage(HitCountUpdateMessage)

C2cRpcRequest = _reflection.GeneratedProtocolMessageType('C2cRpcRequest', (_message.Message,), {
  'DESCRIPTOR' : _C2CRPCREQUEST,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.C2cRpcRequest)
  })
_sym_db.RegisterMessage(C2cRpcRequest)

C2cRpcResponse = _reflection.GeneratedProtocolMessageType('C2cRpcResponse', (_message.Message,), {
  'DESCRIPTOR' : _C2CRPCRESPONSE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.C2cRpcResponse)
  })
_sym_db.RegisterMessage(C2cRpcResponse)

StartDatastoreConnectivityTestCommand = _reflection.GeneratedProtocolMessageType('StartDatastoreConnectivityTestCommand', (_message.Message,), {
  'DESCRIPTOR' : _STARTDATASTORECONNECTIVITYTESTCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.StartDatastoreConnectivityTestCommand)
  })
_sym_db.RegisterMessage(StartDatastoreConnectivityTestCommand)

DatastoreConnectivityTestC2cResponse = _reflection.GeneratedProtocolMessageType('DatastoreConnectivityTestC2cResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATASTORECONNECTIVITYTESTC2CRESPONSE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.DatastoreConnectivityTestC2cResponse)
  })
_sym_db.RegisterMessage(DatastoreConnectivityTestC2cResponse)

PingDatastoreCommand = _reflection.GeneratedProtocolMessageType('PingDatastoreCommand', (_message.Message,), {
  'DESCRIPTOR' : _PINGDATASTORECOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.PingDatastoreCommand)
  })
_sym_db.RegisterMessage(PingDatastoreCommand)

DatastoreInformation = _reflection.GeneratedProtocolMessageType('DatastoreInformation', (_message.Message,), {
  'DESCRIPTOR' : _DATASTOREINFORMATION,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.DatastoreInformation)
  })
_sym_db.RegisterMessage(DatastoreInformation)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.rookout.rook.protobufZ2github.com/Rookout/management/pkg/protos/protobuf2'
  _LOGMESSAGE.fields_by_name['formatted_message']._options = None
  _LOGMESSAGE.fields_by_name['formatted_message']._serialized_options = b'\030\001'
  _LOGMESSAGE.fields_by_name['legacy_arguments']._options = None
  _LOGMESSAGE.fields_by_name['legacy_arguments']._serialized_options = b'\030\001'
  _CONTROLLERLOGMESSAGE_METADATAENTRY._options = None
  _CONTROLLERLOGMESSAGE_METADATAENTRY._serialized_options = b'8\001'
  _CONTROLLERLOGMESSAGE_METADATAJSONVALUESENTRY._options = None
  _CONTROLLERLOGMESSAGE_METADATAJSONVALUESENTRY._serialized_options = b'8\001'
  _AUGREPORTMESSAGE_STRINGSCACHEENTRY._options = None
  _AUGREPORTMESSAGE_STRINGSCACHEENTRY._serialized_options = b'8\001'
  _INITIALAUGSCOMMAND_SDKCONFIGURATIONENTRY._options = None
  _INITIALAUGSCOMMAND_SDKCONFIGURATIONENTRY._serialized_options = b'8\001'
  _DATAONPREMTOKENACCESSTYPE._serialized_start=3803
  _DATAONPREMTOKENACCESSTYPE._serialized_end=3851
  _NEWAGENTMESSAGE._serialized_start=163
  _NEWAGENTMESSAGE._serialized_end=231
  _STACKFRAME._serialized_start=233
  _STACKFRAME._serialized_end=295
  _STACKTRACE._serialized_start=297
  _STACKTRACE._serialized_end=350
  _EXCEPTION._serialized_start=352
  _EXCEPTION._serialized_end=478
  _LOGMESSAGE._serialized_start=481
  _LOGMESSAGE._serialized_end=963
  _LOGMESSAGE_LOGLEVEL._serialized_start=886
  _LOGMESSAGE_LOGLEVEL._serialized_end=963
  _CONTROLLERLOGMESSAGE._serialized_start=966
  _CONTROLLERLOGMESSAGE._serialized_end=1641
  _CONTROLLERLOGMESSAGE_ERROR._serialized_start=1416
  _CONTROLLERLOGMESSAGE_ERROR._serialized_end=1454
  _CONTROLLERLOGMESSAGE_METADATAENTRY._serialized_start=1456
  _CONTROLLERLOGMESSAGE_METADATAENTRY._serialized_end=1503
  _CONTROLLERLOGMESSAGE_METADATAJSONVALUESENTRY._serialized_start=1505
  _CONTROLLERLOGMESSAGE_METADATAJSONVALUESENTRY._serialized_end=1562
  _CONTROLLERLOGMESSAGE_LOGLEVEL._serialized_start=886
  _CONTROLLERLOGMESSAGE_LOGLEVEL._serialized_end=963
  _RULESTATUSMESSAGE._serialized_start=1644
  _RULESTATUSMESSAGE._serialized_end=1772
  _AUGREPORTMESSAGE._serialized_start=1775
  _AUGREPORTMESSAGE._serialized_end=2143
  _AUGREPORTMESSAGE_STRINGSCACHEENTRY._serialized_start=2092
  _AUGREPORTMESSAGE_STRINGSCACHEENTRY._serialized_end=2143
  _USERMSG._serialized_start=2145
  _USERMSG._serialized_end=2246
  _ADDAUGCOMMAND._serialized_start=2248
  _ADDAUGCOMMAND._serialized_end=2281
  _INITIALAUGSCOMMAND._serialized_start=2284
  _INITIALAUGSCOMMAND._serialized_end=2457
  _INITIALAUGSCOMMAND_SDKCONFIGURATIONENTRY._serialized_start=2402
  _INITIALAUGSCOMMAND_SDKCONFIGURATIONENTRY._serialized_end=2457
  _REMOVEAUGCOMMAND._serialized_start=2459
  _REMOVEAUGCOMMAND._serialized_end=2493
  _INITFINISHEDMESSAGE._serialized_start=2495
  _INITFINISHEDMESSAGE._serialized_end=2516
  _CLEARAUGSCOMMAND._serialized_start=2518
  _CLEARAUGSCOMMAND._serialized_end=2536
  _PINGMESSAGE._serialized_start=2538
  _PINGMESSAGE._serialized_end=2566
  _ERRORMESSAGE._serialized_start=2568
  _ERRORMESSAGE._serialized_end=2599
  _C2CINITMESSAGE._serialized_start=2601
  _C2CINITMESSAGE._serialized_end=2702
  _DATAONPREMTOKENREQUEST._serialized_start=2704
  _DATAONPREMTOKENREQUEST._serialized_end=2789
  _DATAONPREMTOKENRESPONSE._serialized_start=2791
  _DATAONPREMTOKENRESPONSE._serialized_end=2831
  _AGENTSLIST._serialized_start=2833
  _AGENTSLIST._serialized_end=2865
  _ASSERTAGENTS._serialized_start=2867
  _ASSERTAGENTS._serialized_end=2900
  _INVALIDATEAGENTSCOMMAND._serialized_start=2902
  _INVALIDATEAGENTSCOMMAND._serialized_end=2947
  _CONFIRMAGENTSCOMMAND._serialized_start=2949
  _CONFIRMAGENTSCOMMAND._serialized_end=2991
  _AGENTIDHITCOUNTPAIR._serialized_start=2993
  _AGENTIDHITCOUNTPAIR._serialized_end=3051
  _HITCOUNTUPDATEMESSAGE._serialized_start=3053
  _HITCOUNTUPDATEMESSAGE._serialized_end=3155
  _C2CRPCREQUEST._serialized_start=3157
  _C2CRPCREQUEST._serialized_end=3233
  _C2CRPCRESPONSE._serialized_start=3235
  _C2CRPCRESPONSE._serialized_end=3327
  _STARTDATASTORECONNECTIVITYTESTCOMMAND._serialized_start=3329
  _STARTDATASTORECONNECTIVITYTESTCOMMAND._serialized_end=3448
  _DATASTORECONNECTIVITYTESTC2CRESPONSE._serialized_start=3450
  _DATASTORECONNECTIVITYTESTC2CRESPONSE._serialized_end=3573
  _PINGDATASTORECOMMAND._serialized_start=3575
  _PINGDATASTORECOMMAND._serialized_end=3619
  _DATASTOREINFORMATION._serialized_start=3622
  _DATASTOREINFORMATION._serialized_end=3801
# @@protoc_insertion_point(module_scope)
