# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: controller_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x63ontroller_info.proto\x12\x0b\x63om.rookout\"\xf6\x01\n\x15\x43ontrollerInformation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x63ommit\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x10\n\x08hostname\x18\x05 \x01(\t\x12\x14\n\x0cmachine_type\x18\x06 \x01(\t\x12\x0f\n\x07network\x18\x07 \x01(\t\x12\n\n\x02ip\x18\x08 \x01(\t\x12\x10\n\x08platform\x18\t \x01(\t\x12\x18\n\x10platform_release\x18\n \x01(\t\x12\x18\n\x10platform_version\x18\x0b \x01(\t\x12\x17\n\x0fplatform_string\x18\x0c \x01(\tBO\n\x19\x63om.rookout.rook.protobufZ2github.com/Rookout/management/pkg/protos/protobuf2b\x06proto3')



_CONTROLLERINFORMATION = DESCRIPTOR.message_types_by_name['ControllerInformation']
ControllerInformation = _reflection.GeneratedProtocolMessageType('ControllerInformation', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLLERINFORMATION,
  '__module__' : 'controller_info_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.ControllerInformation)
  })
_sym_db.RegisterMessage(ControllerInformation)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.rookout.rook.protobufZ2github.com/Rookout/management/pkg/protos/protobuf2'
  _CONTROLLERINFORMATION._serialized_start=39
  _CONTROLLERINFORMATION._serialized_end=285
# @@protoc_insertion_point(module_scope)
