#include "common.h"

namespace native_extensions {

#define NATIVE_EXTENSION_MODULE_NAME "native_extensions"
#define NATIVE_EXTENSION_SCOPE_NAME(n)     NATIVE_EXTENSION_MODULE_NAME "." n

void InitNativeExtensions();


}  // namespace native_extensions
